@@ -1,6 +1,6 @@
 package Bread::Board;
 our $AUTHORITY = 'cpan:STEVAN';
-$Bread::Board::VERSION = '0.34';
+$Bread::Board::VERSION = '0.35';
 use strict;
 use warnings;
 use Carp qw(confess);
@@ -19,21 +19,38 @@ use Bread::Board::LifeCycle::Singleton;
 use Bread::Board::Service::Inferred;
 use Bread::Board::Service::Alias;
 
-use Moose::Exporter 2.1200;
-Moose::Exporter->setup_import_methods(
-    as_is => [qw[
-        as
-        container
-        depends_on
-        service
-        alias
-        wire_names
-        include
-        typemap
-        infer
-        literal
-    ]],
-);
+use Exporter qw( import );
+
+our @EXPORT = qw[
+    as
+    container
+    depends_on
+    service
+    alias
+    wire_names
+    include
+    typemap
+    infer
+    literal
+];
+
+# This is a chopped down version of what's in Moose::Exporter. It'd be nice if
+# there was something on CPAN that implemented this without all the additional
+# Moose::Exporter baggage (particularly the enabling of strict & warnings).
+sub unimport {
+    my $package = caller();
+
+    foreach my $name (@EXPORT) {
+        no strict 'refs';
+        next unless defined &{ $package . '::' . $name };
+
+        my $sub = \&{ $package . '::' . $name };
+
+        next unless $sub eq __PACKAGE__->can($name);
+
+        delete ${ $package . '::' }{$name};
+    }
+}
 
 sub as (&) { $_[0] }
 
@@ -260,7 +277,7 @@ Bread::Board - A solderless way to wire up your application components
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -759,7 +776,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Infinity Interactive.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2011, 2009 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
