@@ -1,6 +1,6 @@
 package Bread::Board::Container::Parameterized;
 our $AUTHORITY = 'cpan:STEVAN';
-$Bread::Board::Container::Parameterized::VERSION = '0.34';
+$Bread::Board::Container::Parameterized::VERSION = '0.35';
 use Moose;
 use Moose::Util 'find_meta';
 use Bread::Board::Container::FromParameterized;
@@ -33,12 +33,14 @@ has 'container' => (
         has_service
         get_service_list
         has_services
+        services
 
         add_sub_container
         get_sub_container
         has_sub_container
         get_sub_container_list
         has_sub_containers
+        sub_containers
     ]]
 );
 
@@ -112,7 +114,7 @@ Bread::Board::Container::Parameterized - A parameterized container
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 DESCRIPTION
 
@@ -206,7 +208,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Infinity Interactive.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2011, 2009 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
